Implementation of embedded_hal traits for MSP430FR2x5x family of microcontrollers.
Here are the datasheet and User's guide for reference.
As of this writing, the only supported board is the MSP430FR2355.
Usage
Requires msp430-elf-gcc installed and in $PATH to build
When using this crate as a dependency, make sure you include the appropriate memory.x file for
your microcontroller.
Examples
The examples/ directory contains binary code examples using the HAL abstractions.
To flash the examples, make sure you have mspdebug with tilib support installed and in
$PATH. Invoke cargo run --example whatever with the board plugged and the scripts should do
the trick, assuming your host is Linux and you are connected via Launchpad.
Features
An implementation of the pre-1.0 version of embedded-hal (e.g. 0.2.7 at time of writing) is
available behind the embedded-hal-02 feature flag. These traits are implemented on the same
structs as the current embedded-hal implementation, so with this feature enabled you may mix and
match crates that require the pre-1.0 version with those that require the latest version. It isn’t enabled by
default, as many of the trait names are similar (or identical) to their counterparts in the current
version, which can be confusing.
Re-exports
pub use msp430fr2355 as pac;pub use embedded_hal as ehal;
Modules
- adc
- Analog to Digital Converter (ADC)
- bak_mem
- Backup Memory. 32 bytes of memory that survive system resets.
- batch_
gpio - GPIO batch configuration.
- capture
- Capture ports
- clock
- Clock system for configuration of MCLK, SMCLK, and ACLK.
- crc
- Cyclic Redundancy Check (CRC).
- delay
- Embedded hal delay implementation
- ecomp
- Enhanced Comparator (eCOMP)
- fram
- FRAM controller
- gpio
- GPIO abstractions for configuring and controlling individual GPIO pins.
- i2c
- I2C
- info_
mem - Information Memory. 512 bytes of non-volatile memory.
- lpm
- Low Power Mode (LPM) control
- pmm
- Power management module
- prelude
- Prelude
- pwm
- PWM ports
- rtc
- Real time counter
- sac
- Smart Analog Combo (SAC)
- serial
- Serial UART
- spi
- SPI
- timer
- Countdown timers
- watchdog
- Watchdog timer, configurable as either a traditional watchdog or a 16-bit timer.